@@ -14,6 +14,7 @@
 
 #include <kmessagebox.h>
 #include <KLocalizedString>
+#include <KLanguageName>
 #include <kstandardaction.h>
 #include <kstandardshortcut.h>
 #include <kstandardgameaction.h>
@@ -41,8 +42,6 @@
 #include "soundfactory.h"
 #include "playgrounddelegate.h"
 
-// TODO kdelibs4support REMOVE
-#include <KLocale>
 
 static const char *DEFAULT_THEME = "default_theme.theme";
 
@@ -95,7 +94,7 @@ void TopLevel::registerGameboard(const QString &menuText, const QString &board,
   connect(t, SIGNAL(toggled(bool)), SLOT(changeGameboard()));
   playgroundsGroup->addAction(t);
   QList<QAction*> actionList = playgroundsGroup->actions();
-  qSort(actionList.begin(), actionList.end(), actionSorterByName);
+  std::sort(actionList.begin(), actionList.end(), actionSorterByName);
   unplugActionList( QStringLiteral( "playgroundList" ) );
   plugActionList( QStringLiteral( "playgroundList" ), actionList );
 
@@ -106,7 +105,7 @@ void TopLevel::registerGameboard(const QString &menuText, const QString &board,
 // Register an available language
 void TopLevel::registerLanguage(const QString &code, const QString &soundFile, bool enabled)
 {
-  KToggleAction *t = new KToggleAction(KLocale::global()->languageCodeToName(code), this);
+  KToggleAction *t = new KToggleAction(KLanguageName::nameForCode(code), this);
   t->setEnabled(enabled);
   actionCollection()->addAction(soundFile, t);
   t->setData(soundFile);
@@ -115,7 +114,7 @@ void TopLevel::registerLanguage(const QString &code, const QString &soundFile, b
   languagesGroup->addAction(t);
   QList<QAction*> actionList = languagesGroup->actions();
   actionList.removeAll(actionCollection()->action(QStringLiteral( "speech_no_sound" )));
-  qSort(actionList.begin(), actionList.end(), actionSorterByName);
+  std::sort(actionList.begin(), actionList.end(), actionSorterByName);
   unplugActionList( QStringLiteral( "languagesList" ) );
   plugActionList( QStringLiteral( "languagesList" ), actionList );
 }
@@ -233,14 +232,25 @@ void TopLevel::readOptions(QString &board, QString &language)
   language = config.readEntry("Language", "" );
   bool keepAspectRatio = config.readEntry("KeepAspectRatio", false);
 
-  if (soundEnabled)
+  if (soundEnabled && language.isEmpty())
   {
+    const QStringList &systemLanguages = KLocalizedString::languages();
+    for (const QString &systemLanguage : systemLanguages)
+    {
+      QString sound = sounds.value(systemLanguage);
+      if (!sound.isEmpty())
+      {
+        language = sound;
+        break;
+      }
+    }
     if (language.isEmpty())
     {
-      language = sounds.value(KLocale::global()->language(), QStringLiteral( "en.soundtheme" ));
+      language = QStringLiteral("en.soundtheme");
     }
   }
-  else
+
+  if (!soundEnabled)
   {
     soundOff();
     language = QString();
@@ -425,7 +435,7 @@ void TopLevel::filePicture()
   const QMimeDatabase mimedb;
   const QList<QByteArray> imageWriterMimetypes = QImageWriter::supportedMimeTypes();
   QStringList patterns;
-  for(auto mimeName : imageWriterMimetypes)
+  for(const auto &mimeName : imageWriterMimetypes)
   {
     const QMimeType mime = mimedb.mimeTypeForName(mimeName);
     if (mime.isValid())
@@ -433,7 +443,7 @@ void TopLevel::filePicture()
       QStringList suffixes;
       for(const QString &suffix : mime.suffixes())
       {
-          suffixes << QString("*.%1").arg(suffix);
+          suffixes << QStringLiteral("*.%1").arg(suffix);
       }
 
       // Favor png
@@ -448,7 +458,7 @@ void TopLevel::filePicture()
       }
     }
   }
-  const QUrl url = QFileDialog::getSaveFileUrl( this, QString(), QUrl(), patterns.join(";;") );
+  const QUrl url = QFileDialog::getSaveFileUrl( this, QString(), QUrl(), patterns.join(QStringLiteral(";;")) );
 
   if( url.isEmpty() )
     return;
